@@ -3,10 +3,12 @@ import subprocess
 import sys
 import time
 from importlib.metadata import entry_points
+from typing import Any
 
 import click
 
 from plain.cli import register_cli
+from plain.cli.runtime import common_command
 from plain.runtime import APP_PATH, PLAIN_TEMP_PATH
 
 from .alias import AliasManager
@@ -17,12 +19,12 @@ from .services import ServicesProcess
 class DevGroup(click.Group):
     """Custom group that ensures *services* are running on CLI startup."""
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
         self._auto_start_services()
 
     @staticmethod
-    def _auto_start_services():
+    def _auto_start_services() -> None:
         """Start dev *services* in the background if not already running."""
 
         # Check if we're in CI and auto-start is not explicitly enabled
@@ -79,6 +81,7 @@ class DevGroup(click.Group):
             sys.exit(1)
 
 
+@common_command
 @register_cli("dev")
 @click.group(cls=DevGroup, invoke_without_command=True)
 @click.pass_context
@@ -118,8 +121,15 @@ class DevGroup(click.Group):
     default=False,
     help="Stop the background process",
 )
-def cli(ctx, port, hostname, log_level, start, stop):
-    """Start local development"""
+def cli(
+    ctx: click.Context,
+    port: str,
+    hostname: str | None,
+    log_level: str,
+    start: bool,
+    stop: bool,
+) -> None:
+    """Local development server"""
     if ctx.invoked_subcommand:
         return
 
@@ -173,17 +183,21 @@ def cli(ctx, port, hostname, log_level, start, stop):
     # Check and prompt for alias setup
     AliasManager().check_and_prompt()
 
-    dev.setup(port=port, hostname=hostname, log_level=log_level)
+    dev.setup(
+        port=int(port) if port else None,
+        hostname=hostname,
+        log_level=log_level if log_level else None,
+    )
     returncode = dev.run()
     if returncode:
         sys.exit(returncode)
 
 
 @cli.command()
-def debug():
+def debug() -> None:
     """Connect to the remote debugger"""
 
-    def _connect():
+    def _connect() -> subprocess.CompletedProcess[bytes]:
         if subprocess.run(["which", "nc"], capture_output=True).returncode == 0:
             return subprocess.run(["nc", "-C", "localhost", "4444"])
         else:
@@ -208,8 +222,8 @@ def debug():
 @cli.command()
 @click.option("--start", is_flag=True, help="Start in the background")
 @click.option("--stop", is_flag=True, help="Stop the background process")
-def services(start, stop):
-    """Start additional services defined in pyproject.toml"""
+def services(start: bool, stop: bool) -> None:
+    """Start additional development services"""
 
     if start and stop:
         raise click.UsageError(
@@ -248,8 +262,8 @@ def services(start, stop):
 @click.option("--pid", type=int, help="PID to show logs for")
 @click.option("--path", is_flag=True, help="Output log file path")
 @click.option("--services", is_flag=True, help="Show logs for services")
-def logs(follow, pid, path, services):
-    """Show logs from recent plain dev runs."""
+def logs(follow: bool, pid: int | None, path: bool, services: bool) -> None:
+    """Show recent development logs"""
 
     if services:
         log_dir = PLAIN_TEMP_PATH / "dev" / "logs" / "services"
@@ -284,8 +298,8 @@ def logs(follow, pid, path, services):
     "--list", "-l", "show_list", is_flag=True, help="List available entrypoints"
 )
 @click.argument("entrypoint", required=False)
-def entrypoint(show_list, entrypoint):
-    """Entrypoints registered under plain.dev"""
+def entrypoint(show_list: bool, entrypoint: str | None) -> None:
+    """Run registered development entrypoints"""
     if not show_list and not entrypoint:
         raise click.UsageError("Please provide an entrypoint name or use --list")
 
