@@ -26,7 +26,9 @@ class DevProcess(ProcessManager):
     pidfile = PLAIN_TEMP_PATH / "dev" / "dev.pid"
     log_dir = PLAIN_TEMP_PATH / "dev" / "logs" / "run"
 
-    def setup(self, *, port, hostname, log_level):
+    def setup(
+        self, *, port: int | None, hostname: str | None, log_level: str | None
+    ) -> None:
         if not hostname:
             project_name = os.path.basename(
                 os.getcwd()
@@ -66,6 +68,7 @@ class DevProcess(ProcessManager):
         self.plain_env = {
             "PYTHONUNBUFFERED": "true",
             "PLAIN_DEV": "true",
+            "FORCE_COLOR": "1",
             **os.environ,
         }
 
@@ -112,19 +115,19 @@ class DevProcess(ProcessManager):
 
         self.init_poncho(self.console.out)
 
-    def _find_open_port(self, start_port):
+    def _find_open_port(self, start_port: int) -> int:
         port = start_port
         while not self._port_available(port):
             port += 1
         return port
 
-    def _port_available(self, port):
+    def _port_available(self, port: int) -> bool:
         with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
             sock.settimeout(0.5)
             result = sock.connect_ex(("127.0.0.1", port))
         return result != 0
 
-    def run(self):
+    def run(self) -> int:
         self.write_pidfile()
         mkcert_manager = MkcertManager()
         mkcert_manager.setup_mkcert(install_path=Path.home() / ".plain" / "dev")
@@ -134,6 +137,7 @@ class DevProcess(ProcessManager):
         )
 
         self.symlink_plain_src()
+        self.generate_agents_md()
         self.modify_hosts_file()
 
         click.secho("→ Running preflight checks... ", dim=True, nl=False)
@@ -148,7 +152,7 @@ class DevProcess(ProcessManager):
         if find_spec("plain.models"):
             click.secho("→ Waiting for database... ", dim=True, nl=False)
             subprocess.run(
-                [sys.executable, "-m", "plain", "models", "db-wait"],
+                [sys.executable, "-m", "plain", "db", "wait"],
                 env=self.plain_env,
                 check=True,
             )
@@ -165,7 +169,7 @@ class DevProcess(ProcessManager):
         # another thread checking db stuff...
         self.console_status.start()
 
-        self.add_gunicorn()
+        self.add_server()
         self.add_entrypoints()
         self.add_pyproject_run()
 
@@ -181,9 +185,12 @@ class DevProcess(ProcessManager):
 
         return self.poncho.returncode
 
-    def symlink_plain_src(self):
+    def symlink_plain_src(self) -> None:
         """Symlink the plain package into .plain so we can look at it easily"""
-        plain_path = Path(find_spec("plain.runtime").origin).parent.parent
+        spec = find_spec("plain.runtime")
+        if spec is None or spec.origin is None:
+            return None
+        plain_path = Path(spec.origin).parent.parent
         if not PLAIN_TEMP_PATH.exists():
             PLAIN_TEMP_PATH.mkdir()
 
@@ -204,7 +211,29 @@ class DevProcess(ProcessManager):
         if plain_path.exists() and not symlink_path.exists():
             symlink_path.symlink_to(plain_path)
 
-    def modify_hosts_file(self):
+    def generate_agents_md(self) -> None:
+        """Generate .plain/AGENTS.md from installed packages with AGENTS.md files."""
+        try:
+            result = subprocess.run(
+                [sys.executable, "-m", "plain", "agent", "md", "--save"],
+                check=False,
+                capture_output=True,
+                text=True,
+            )
+            if result.returncode != 0 and result.stderr:
+                click.secho(
+                    f"Warning: Failed to generate .plain/AGENTS.md: {result.stderr}",
+                    fg="yellow",
+                    err=True,
+                )
+        except Exception as e:
+            click.secho(
+                f"Warning: Failed to generate .plain/AGENTS.md: {e}",
+                fg="yellow",
+                err=True,
+            )
+
+    def modify_hosts_file(self) -> None:
         """Modify the hosts file to map the custom domain to 127.0.0.1."""
         entry_identifier = "# Added by plain"
         hosts_entry = f"127.0.0.1 {self.hostname}  {entry_identifier}"
@@ -259,25 +288,20 @@ class DevProcess(ProcessManager):
                 )
                 sys.exit(1)
 
-    def run_preflight(self):
+    def run_preflight(self) -> None:
         if subprocess.run(
-            ["plain", "preflight", "check", "--quiet"], env=self.plain_env
+            ["plain", "preflight", "--quiet"], env=self.plain_env
         ).returncode:
             click.secho("Preflight check failed!", fg="red")
             sys.exit(1)
 
-    def add_gunicorn(self):
-        # Watch .env files for reload
-        extra_watch_files = []
-        for f in os.listdir(APP_PATH.parent):
-            if f.startswith(".env"):
-                # Needs to be absolute or "./" for inotify to work on Linux...
-                # https://github.com/dropseed/plain/issues/26
-                extra_watch_files.append(str(Path(APP_PATH.parent) / f))
-
-        reload_extra = " ".join(f"--reload-extra-file {f}" for f in extra_watch_files)
-        gunicorn_cmd = [
-            "gunicorn",
+    def add_server(self) -> None:
+        """Add the Plain HTTP server process."""
+        server_cmd = [
+            sys.executable,
+            "-m",
+            "plain",
+            "server",
             "--bind",
             f"{self.hostname}:{self.port}",
             "--certfile",
@@ -286,27 +310,21 @@ class DevProcess(ProcessManager):
             str(self.ssl_key_path),
             "--threads",
             "4",
-            "--reload",
-            "plain.wsgi:app",
             "--timeout",
             "60",
             "--log-level",
             self.log_level or "info",
-            "--access-logfile",
-            "-",
-            "--error-logfile",
-            "-",
-            *reload_extra.split(),
-            "--access-logformat",
+            "--log-format",
+            "'[%(levelname)s] %(message)s'",
+            "--access-log-format",
             "'\"%(r)s\" status=%(s)s length=%(b)s time=%(M)sms'",
-            "--log-config-json",
-            str(Path(__file__).parent / "gunicorn_logging.json"),
+            "--reload",  # Enable auto-reload for development
         ]
-        gunicorn = " ".join(gunicorn_cmd)
 
-        self.poncho.add_process("plain", gunicorn, env=self.plain_env)
+        server = " ".join(server_cmd)
+        self.poncho.add_process("plain", server, env=self.plain_env)
 
-    def add_entrypoints(self):
+    def add_entrypoints(self) -> None:
         for entry_point in entry_points().select(group=ENTRYPOINT_GROUP):
             self.poncho.add_process(
                 entry_point.name,
@@ -314,7 +332,7 @@ class DevProcess(ProcessManager):
                 env=self.plain_env,
             )
 
-    def add_pyproject_run(self):
+    def add_pyproject_run(self) -> None:
         """Additional processes that only run during `plain dev`."""
         if not has_pyproject_toml(APP_PATH.parent):
             return
