@@ -18,15 +18,15 @@ if ON_WINDOWS:
 class ProcessManager:
     if ON_WINDOWS:
 
-        def terminate(self, pid):
+        def terminate(self, pid: int) -> None:
             # The first argument to OpenProcess represents the desired access
             # to the process. 1 represents the PROCESS_TERMINATE access right.
-            handle = ctypes.windll.kernel32.OpenProcess(1, False, pid)
-            ctypes.windll.kernel32.TerminateProcess(handle, -1)
-            ctypes.windll.kernel32.CloseHandle(handle)
+            handle = ctypes.windll.kernel32.OpenProcess(1, False, pid)  # type: ignore[attr-defined]
+            ctypes.windll.kernel32.TerminateProcess(handle, -1)  # type: ignore[attr-defined]
+            ctypes.windll.kernel32.CloseHandle(handle)  # type: ignore[attr-defined]
     else:
 
-        def terminate(self, pid):
+        def terminate(self, pid: int) -> None:
             try:
                 os.killpg(pid, signal.SIGTERM)
             except OSError as e:
@@ -35,12 +35,12 @@ class ProcessManager:
 
     if ON_WINDOWS:
 
-        def kill(self, pid):
+        def kill(self, pid: int) -> None:
             # There's no SIGKILL on Win32...
             self.terminate(pid)
     else:
 
-        def kill(self, pid):
+        def kill(self, pid: int) -> None:
             try:
                 os.killpg(pid, signal.SIGKILL)
             except OSError as e:
